@@ -152,7 +152,8 @@ class Generator:
         return "\n".join(lines)
 
     def _generate_option(self, option: ast.Option, indent_level: int = 0) -> str:
-        return f"{'  ' * indent_level}option {option.name} = \"{option.value}\";"
+        value = self._generate_scalar(option.value)
+        return f"{'  ' * indent_level}option {option.name} = {value};"
 
     def _generate_extension(
         self, extension: ast.Extension, indent_level: int = 0
@@ -201,6 +202,15 @@ class Generator:
         reserved_values = ", ".join(itertools.chain(reserved.ranges, reserved.names))
         return f"{'  ' * indent_level}reserved {reserved_values};"
 
+    def _generate_scalar(
+        self, scalar: str | int | float | bool | ast.Identifier
+    ) -> str | int | float | bool:
+        if isinstance(scalar, str):
+            return f'"{scalar}"'
+        elif isinstance(scalar, ast.Identifier):
+            return scalar.name
+        return scalar
+
     @staticmethod
     def _indent(line: str, indent_level: int = 0) -> str:
         return f"{'  ' * indent_level}{line}"
