@@ -21,7 +21,7 @@ class ASTConstructor(ProtobufParserVisitor):
         return ast.File(syntax=syntax, file_elements=file_elements)
 
     def visitCommentDecl(self, ctx: ProtobufParser.CommentDeclContext):
-        return ast.Comment(text=self._getText(ctx))
+        return ast.Comment(text=self._getText(ctx, False))
 
     def visitPackageDecl(self, ctx: ProtobufParser.PackageDeclContext):
         name = self._getText(ctx.packageName())
@@ -35,9 +35,15 @@ class ASTConstructor(ProtobufParserVisitor):
 
     def visitOptionDecl(self, ctx: ProtobufParser.OptionDeclContext):
         name = self._getText(ctx.optionName())
-        value = self._getText(ctx.optionValue())
+        value = self.visit(ctx.optionValue())
         return ast.Option(name=name, value=value)
 
+    def visitOptionValue(self, ctx: ProtobufParser.OptionValueContext | Any):
+        if ctx.scalarValue():
+            return self.visit(ctx.scalarValue())
+
+        return self._getText(ctx)
+
     def visitMessageDecl(self, ctx: ProtobufParser.MessageDeclContext):
         name = self._getText(ctx.messageName())
         elements = [self.visit(child) for child in ctx.messageElement()]
@@ -245,8 +251,34 @@ class ASTConstructor(ProtobufParserVisitor):
         else:
             raise AttributeError("invalid method element")
 
+    def visitScalarValue(self, ctx: ProtobufParser.ScalarValueContext):
+        if ctx.stringLiteral():
+            return self._getText(ctx.stringLiteral())
+        elif ctx.intLiteral() or ctx.floatLiteral():
+            return self._stringToType(self._getText(ctx))
+        elif ctx.specialFloatLiteral():
+            # TODO Handle specialFloatLiteral -inf, inf, nan properly
+            return self._getText(ctx)
+        elif ctx.identifier():
+            return self.visit(ctx.identifier())
+        # ctx.identifier()
+        return self.visit(ctx.identifier())
+
+    def visitAlwaysIdent(self, ctx: ProtobufParser.AlwaysIdentContext | Any):
+        if ctx.IDENTIFIER():
+            # Unlike string/int/float, bools are just reated as identiifers in
+            # the lexer, so we need to handle them here
+            identifier_text = self._getText(ctx)
+            if identifier_text in ["true", "false"]:
+                return identifier_text == "true"
+            return ast.Identifier(name=identifier_text)
+
+        return super().visitAlwaysIdent(ctx)
+
     # ctx: ParserRuleContext, but ANTLR generates untyped code
-    def _getText(self, ctx: Any, stripQuotes: bool = True):
+    def _getText(self, ctx: Any, strip_quotes: bool = True):
+        """ """
+
         token_source = (
             ctx.start.getTokenSource()
         )  # pyright: ignore [reportGeneralTypeIssues]
@@ -256,7 +288,31 @@ class ASTConstructor(ProtobufParserVisitor):
             ctx.stop.stop,
         )  # pyright: ignore [reportGeneralTypeIssues]
         text = input_stream.getText(start, stop)
-        return text.strip('"') if stripQuotes else text
+        text = text.strip('"') if strip_quotes else text
+        return text
+
+    def _stringToType(self, value: str):
+        """
+        Convert a string to a bool, int, or float if possible.
+
+        Args:
+            value: The string to convert.
+
+        Returns:
+            The converted value if possible, otherwise the original string.
+        """
+
+        if value.lower() in ["true", "false"]:
+            return value.lower() == "true"
+        try:
+            return int(value)
+        except ValueError:
+            pass
+        try:
+            return float(value)
+        except ValueError:
+            pass
+        return value
 
 
 class Parser:
